==> rest-sdk-commons-0.7.1-sources.jar: com/mulesoft/connectivity/rest/commons/api/connection/oauth/BaseClientCredentialsConnectionProvider.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.commons.api.connection.oauth;

import com.mulesoft.connectivity.rest.commons.api.connection.BaseConnectionProvider;
import com.mulesoft.connectivity.rest.commons.api.connection.RestConnection;
import org.mule.runtime.api.util.MultiMap;
import org.mule.runtime.extension.api.connectivity.oauth.ClientCredentialsState;
import org.mule.runtime.http.api.client.HttpClient;
import org.mule.runtime.http.api.client.auth.HttpAuthentication;

/**
 * Base class for Connection Providers that authenticate using OAuth with the Authorization Code Grant Type
 *
 * @since 1.0
 */
public abstract class BaseClientCredentialsConnectionProvider extends BaseConnectionProvider {

  private ClientCredentialsState oauthState;


  @Override
  protected RestConnection createConnection(HttpClient httpClient,
                                            HttpAuthentication authentication,
                                            MultiMap<String, String> defaultQueryParams,
                                            MultiMap<String, String> defaultHeaders) {
    return new OAuthRestConnection(getBaseUri(),
                                   getConfigName(),
                                   httpClient,
                                   authentication,
                                   defaultQueryParams,
                                   defaultHeaders,
                                   getOAuthState(),
                                   "default", getExpressionLanguage(), getRefreshTokenCondition());
  }

  protected ClientCredentialsState getOAuthState() {
    return oauthState;
  }

  protected String getRefreshTokenCondition() {
    return null;
  }
}

==> rest-sdk-commons-0.10.0-sources.jar: com/mulesoft/connectivity/rest/commons/api/connection/oauth/BaseClientCredentialsConnectionProvider.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.commons.api.connection.oauth;

import com.mulesoft.connectivity.rest.commons.api.connection.BaseConnectionProvider;
import com.mulesoft.connectivity.rest.commons.api.connection.RestConnection;
import org.mule.runtime.api.util.MultiMap;
import org.mule.runtime.extension.api.connectivity.oauth.ClientCredentialsState;
import org.mule.runtime.http.api.client.HttpClient;
import org.mule.runtime.http.api.client.auth.HttpAuthentication;

/**
 * Base class for Connection Providers that authenticate using OAuth with the Authorization Code Grant Type
 *
 * @since 1.0
 */
public abstract class BaseClientCredentialsConnectionProvider extends BaseConnectionProvider {

  private ClientCredentialsState oauthState;


  @Override
  protected RestConnection createConnection(HttpClient httpClient,
                                            HttpAuthentication authentication,
                                            MultiMap<String, String> defaultQueryParams,
                                            MultiMap<String, String> defaultHeaders) {
    return new OAuthRestConnection(getBaseUri(),
                                   getConfigName(),
                                   httpClient,
                                   authentication,
                                   defaultQueryParams,
                                   defaultHeaders,
                                   getOAuthState(),
                                   "default", // TODO: Why always 'default' ?
                                   getExpressionLanguage(),
                                   getRefreshTokenCondition());
  }

  protected ClientCredentialsState getOAuthState() {
    return oauthState;
  }

  protected String getRefreshTokenCondition() {
    return null;
  }
}
